"""
Python module generated from Java source file org.bukkit.material.ExtendedRails

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class ExtendedRails(Rails):
    """
    This is the superclass for the DetectorRail and PoweredRail
    classes

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isCurve(self) -> bool:
        ...


    def setDirection(self, face: "BlockFace", isOnSlope: bool) -> None:
        ...


    def clone(self) -> "ExtendedRails":
        ...
