"""
Python module generated from Java source file org.bukkit.block.Comparator

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Comparator(TileState):
    """
    Represents a captured state of an on / off comparator.
    """


